slepc-3.18.0 2022-10-01
Report Typos and Errors

# RGComputeQuadrature

Computes the values of the parameters used in a quadrature rule for a contour integral around the boundary of the region.

### Synopsis

    #include "slepcrg.h"
    PetscErrorCode RGComputeQuadrature(RG rg,RGQuadRule quad,PetscInt n,PetscScalar z[],PetscScalar zn[],PetscScalar w[])

Not Collective

### Input Parameters

| rg | - the region context
| quad | - the type of quadrature
| n | - number of quadrature points to compute

### Output Parameters

| z | - quadrature points
| zn | - normalized quadrature points
| w | - quadrature weights

### Notes

In complex scalars, the values returned in z are often the same as those computed by RGComputeContour(), but this is not the case in real scalars where all output arguments are real.

The computed values change for different quadrature rules (trapezoidal or Chebyshev).

### See Also

RGComputeContour()

### Level

intermediate

### Location

src/sys/classes/rg/rgbasic.c
Index of all RG routines
Table of Contents for all manual pages
Index of all manual pages